
# Slot: has attribute type


connects an attribute to a class that describes it

URI: [biolink:has_attribute_type](https://w3id.org/biolink/vocab/has_attribute_type)


## Domain and Range

[Attribute](Attribute.md) &#8594;  <sub>1..1</sub> [OntologyClass](OntologyClass.md)

## Parents


## Children

 *  [clinical measurement➞has attribute type](clinical_measurement_has_attribute_type.md)

## Used by

 * [Attribute](Attribute.md)
 * [BiologicalSex](BiologicalSex.md)
 * [ClinicalAttribute](ClinicalAttribute.md)
 * [ClinicalCourse](ClinicalCourse.md)
 * [ClinicalModifier](ClinicalModifier.md)
 * [GenotypicSex](GenotypicSex.md)
 * [Inheritance](Inheritance.md)
 * [Onset](Onset.md)
 * [OrganismAttribute](OrganismAttribute.md)
 * [PhenotypicQuality](PhenotypicQuality.md)
 * [PhenotypicSex](PhenotypicSex.md)
 * [SeverityValue](SeverityValue.md)
 * [SocioeconomicAttribute](SocioeconomicAttribute.md)
 * [Zygosity](Zygosity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | samples |
| **Narrow Mappings:** | | LOINC:has_modality_type |
|  | | LOINC:has_view_type |

